@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import re
 import logging
 
@@ -6,8 +8,6 @@ from cached_property import cached_property
 from urllib3.util.url import parse_url as urlparse
 
 from ._fetch import fetch_update
-from ._unregex import expand_pattern, ExpansionError
-
 from ._fixme import (
     # _FIXME_MULTIPLE_RULEST_PREFIXES,
     _FIXME_REJECT_PATTERNS,
@@ -18,8 +18,17 @@ from ._fixme import (
     _FIXME_SUBDOMAIN_PREFIXES,
 )
 
+try:
+    from ._unregex import expand_pattern, ExpansionError
+except ImportError:
+    expand_pattern, ExpansionError = None, None
+
 logger = setup_logger(name="httpseverywhere.rules", level=logging.INFO)
 
+PY2 = str != "".__class__
+if PY2:
+    str = "".__class__
+    expand_pattern = None
 
 # regex sizeof() is broken, and it appears slower;
 # real benchmarking needed
@@ -273,7 +282,7 @@ def _reduce_ruleset(ruleset):
         if len(rules) > 2:
             return False
 
-        last_rule = _Rule(*rules[-1], ruleset)
+        last_rule = _Rule(*rules[-1], ruleset=ruleset)
         if _is_rule_only_force_https(ruleset, last_rule):
             logger.warning(
                 "{} last rule of {} rules reduced to simple force https".format(
@@ -298,6 +307,7 @@ def _reduce_ruleset(ruleset):
         try:
             pattern_targets = rule.pattern_targets
         except ExpansionError as e:
+            # TypeError occurs if sre_yield 0.2.0 was installed
             logger.info(
                 "expansion failure in rule {} {}: {}".format(
                     ruleset.targets, ruleset.rules, e
@@ -465,6 +475,10 @@ def _reduce_rules(rulesets, check=False):
     if isinstance(rulesets, dict):
         rulesets = rulesets["rulesets"]
 
+    if check and not expand_pattern:
+        logger.warning("Rule analysis and simplification only supported on Python 3")
+        check = False
+
     mapping = {}
     domains = set()
     prefix_targets = set()
@@ -521,7 +535,7 @@ def _reduce_rules(rulesets, check=False):
 
         # https://github.com/EFForg/https-everywhere/issues/18892
         if "accounts.google.com.*" in targets or "www.google.com.*" in targets:
-            for item in targets.copy():
+            for item in list(targets):
                 if item.endswith("google.com.*") and item.rstrip(".*") not in targets:
                     targets.append(item.rstrip(".*"))
 
